@@ -8,7 +8,7 @@
 #' condition object, without any other effect. Both functions should
 #' be called directly from an error handler.
 #'
-#' Set the `error` global option to `quote(rlang::entrace())` to
+#' Set the `error` global option to `rlang::entrace` to
 #' transform base errors to rlang errors. These enriched errors
 #' include a backtrace. The RProfile is a good place to set the
 #' handler. See [`rlang_backtrace_on_error`] for details.
@@ -37,7 +37,7 @@
 entrace <- function(cnd, ..., top = NULL, bottom = NULL) {
   check_dots_empty(...)
 
-  if (!missing(cnd) && inherits(cnd, "rlang_error")) {
+  if (!missing(cnd) && is_trace(cnd$trace)) {
     return()
   }
 
@@ -163,7 +163,7 @@ sys_body <- function(n) {
 entrace_handle_top <- function(trace) {
   # Happens with ctrl-c at top-level
   if (!trace_length(trace)) {
-    return()
+    return(entrace_exit())
   }
 
   stop_call <- sys.call(-2)
@@ -174,8 +174,8 @@ entrace_handle_top <- function(trace) {
   from_stop <- is_call(stop_call, "stop", ns = c("", "base"))
 
   # No need to do anything for rlang errors
-  if (from_stop && inherits(cnd, "rlang_error")) {
-    return(NULL)
+  if (from_stop && (is_trace(cnd$trace) || is_true(cnd$rlang_entraced))) {
+    return(entrace_exit())
   }
 
   if (from_stop) {
@@ -199,6 +199,16 @@ entrace_handle_top <- function(trace) {
     cat_line(backtrace_lines)
   }
 
+  entrace_exit()
+}
+
+entrace_exit <- function() {
+  # Disable error handler in non-interactive sessions to force
+  # non-zero exit (#1052, rstudio/bookdown#920)
+  if (!is_interactive()) {
+    options(error = NULL)
+  }
+
   NULL
 }
 
@@ -249,5 +259,5 @@ add_backtrace <- function() {
 with_abort <- function(expr, classes = "error") {
   handlers <- rep_named(classes, list(entrace))
   handle_call <- rlang::expr(withCallingHandlers(expr, !!!handlers))
-  .Call(rlang_eval, handle_call, current_env())
+  .External2(rlang_ext2_eval, handle_call, current_env())
 }
