@@ -286,6 +286,14 @@ repeat_deparse <- function(x, lines = new_lines()) {
   lines$deparse(node_cadr(x))
   lines$get_lines()
 }
+next_deparse <- function(x, lines = new_lines()) {
+  lines$push("next")
+  lines$get_lines()
+}
+break_deparse <- function(x, lines = new_lines()) {
+  lines$push("break")
+  lines$get_lines()
+}
 if_deparse <- function(x, lines = new_lines()) {
   x <- node_cdr(x)
   lines$push("if (")
@@ -322,7 +330,7 @@ operand_deparse <- function(x, parent, side, lines) {
   }
 }
 
-binary_op_deparse <- function(x, lines = new_lines(), space = " ") {
+binary_op_deparse <- function(x, lines = new_lines(), space = " ", sticky_rhs = FALSE) {
   # Constructed call without second argument
   if (is_null(node_cddr(x))) {
     return(call_deparse(x, lines))
@@ -336,6 +344,10 @@ binary_op_deparse <- function(x, lines = new_lines(), space = " ") {
 
   lines$push_sticky(paste0(space, op, space))
 
+  if (sticky_rhs) {
+    lines$make_next_sticky()
+  }
+
   x <- node_cdr(x)
 
   lines$increase_indent()
@@ -350,6 +362,9 @@ spaced_op_deparse <- function(x, lines = new_lines()) {
 unspaced_op_deparse <- function(x, lines = new_lines()) {
   binary_op_deparse(x, lines, space = "")
 }
+tight_op_deparse <- function(x, lines = new_lines()) {
+  binary_op_deparse(x, lines, space = "", sticky_rhs = TRUE)
+}
 
 unary_op_deparse <- function(x, lines = new_lines()) {
   op <- as_string(node_car(x))
@@ -426,7 +441,7 @@ args_deparse <- function(x, lines = new_lines(), delims = c("(", ")")) {
   while (!is_null(x)) {
     tag <- node_tag(x)
     if (!is_null(tag)) {
-      lines$push(as_string(tag))
+      sym_deparse(tag, lines = lines)
       lines$push_sticky(" = ")
       lines$make_next_sticky()
     }
@@ -467,7 +482,7 @@ call_delimited_type <- function(call) {
     return("none")
   }
 
-  op <- which_operator(call)
+  op <- call_parse_type(call)
   if (op == "") {
     return("none")
   }
@@ -531,6 +546,8 @@ op_deparse <- function(op, x, lines) {
     `for` = for_deparse,
     `repeat` = repeat_deparse,
     `if` = if_deparse,
+    `next` = next_deparse,
+    `break` = break_deparse,
     `?` = ,
     `<-` = ,
     `<<-` = ,
@@ -556,9 +573,9 @@ op_deparse <- function(op, x, lines) {
     `:` = ,
     `^` = ,
     `$` = ,
-    `@` = ,
+    `@` = unspaced_op_deparse,
     `::` = ,
-    `:::` = unspaced_op_deparse,
+    `:::` = tight_op_deparse,
     `?unary` = ,
     `~unary` = ,
     `!` = ,
@@ -577,7 +594,7 @@ op_deparse <- function(op, x, lines) {
   lines$get_lines()
 }
 call_deparser <- function(x) {
-  op <- which_operator(x)
+  op <- call_parse_type(x)
   if (op != "") {
     function(x, lines) op_deparse(op, x, lines)
   } else {
