@@ -92,6 +92,26 @@
 #' ```
 #'
 #'
+#' @section Stack semantics of `eval_tidy()`:
+#'
+#' `eval_tidy()` always evaluates in a data mask, even when `data` is
+#' `NULL`. Because of this, it has different stack semantics than
+#' [base::eval()]:
+#'
+#' - Lexical side effects, such as assignment with `<-`, occur in the
+#'   mask rather than `env`.
+#'
+#' - Functions that require the evaluation environment to correspond
+#'   to a frame on the call stack do not work. This is why `return()`
+#'   called from a quosure does not work.
+#'
+#' - The mask environment creates a new branch in the tree
+#'   representation of backtraces (which you can visualise in a
+#'   [browser()] session with `lobstr::cst()`).
+#'
+#' See also [eval_bare()] for more information about these differences.
+#'
+#'
 #' @section Life cycle:
 #'
 #' **rlang 0.3.0**
@@ -150,7 +170,7 @@
 #' }
 #' @export
 eval_tidy <- function(expr, data = NULL, env = caller_env()) {
-  .Call(rlang_eval_tidy, expr, data, env)
+  .External2(rlang_ext2_eval_tidy, expr, data, env)
 }
 
 # Helps work around roxygen loading issues
@@ -204,6 +224,7 @@ print.rlang_fake_data_pronoun <- function(...) cat_line("<pronoun>")
 #' @export
 .data <- structure(list(), class = "rlang_fake_data_pronoun")
 #' @rdname tidyeval-data
+#' @format NULL
 #' @export
 .env <- .data
 
@@ -303,35 +324,7 @@ print.rlang_fake_data_pronoun <- function(...) cat_line("<pronoun>")
 #' Consequently, all masking data should be contained between the
 #' bottom and top environment of the data mask.
 #'
-#' @section Life cycle:
-#'
-#' The `parent` argument no longer has any effect and is defunct as of
-#' rlang 0.4.0. The parent of the data mask is determined from either:
-#'
-#'   * The `env` argument of `eval_tidy()`
-#'   * Quosure environments when applicable
-#'
-#' Passing environments to `as_data_mask()` is deprecated as of rlang
-#' 0.3.0. Please use `new_data_mask()` instead.
-#'
-#' **rlang 0.2.0**
-#'
-#' In early versions of rlang data masks were called overscopes. We
-#' think data mask is a more natural name in R. It makes reference to
-#' masking in the search path which occurs through the same mechanism
-#' (in technical terms, lexical scoping with hierarchically nested
-#' environments). We say that objects from user data mask objects
-#' in the current environment.
-#'
-#' Following this change in terminology, `as_overscope()` and
-#' `new_overscope()` were deprecated in rlang 0.2.0 in favour of
-#' `as_data_mask()` and `new_data_mask()`.
-#'
 #' @param data A data frame or named vector of masking data.
-#' @param parent Deprecated. This argument no longer has any effect.
-#'   The parent of the data mask is determined from either:
-#'   * The `env` argument of `eval_tidy()`
-#'   * Quosure environments when applicable
 #' @return A data mask that you can supply to [eval_tidy()].
 #'
 #' @export
@@ -399,16 +392,7 @@ print.rlang_fake_data_pronoun <- function(...) cat_line("<pronoun>")
 #'
 #' # Now we can reference the values with the pronouns:
 #' eval_tidy(quote(c(.data$a, .data$b, .data$c)), data = mask)
-as_data_mask <- function(data, parent = NULL) {
-  if (!is_null(parent)) {
-    stop_defunct(paste_line(
-      "The `parent` argument of `as_data_mask()` is deprecated.",
-      "The parent of the data mask is determined from either:",
-      "",
-      "  * The `env` argument of `eval_tidy()`",
-      "  * Quosure environments when applicable"
-    ))
-  }
+as_data_mask <- function(data) {
   .Call(rlang_as_data_mask, data)
 }
 #' @rdname as_data_mask
@@ -433,16 +417,7 @@ as_data_pronoun <- function(data) {
 #'   eval engine and should be considered undetermined. Never make
 #'   assumption about the parent of `top`.
 #' @export
-new_data_mask <- function(bottom, top = bottom, parent = NULL) {
-  if (!is_null(parent)) {
-    stop_defunct(paste_line(
-      "The `parent` argument of `new_data_mask()` is deprecated.",
-      "The parent of the data mask is determined from either:",
-      "",
-      "  * The `env` argument of `eval_tidy()`",
-      "  * Quosure environments when applicable"
-    ))
-  }
+new_data_mask <- function(bottom, top = bottom) {
   .Call(rlang_new_data_mask, bottom, top)
 }
 
@@ -456,7 +431,7 @@ new_data_mask <- function(bottom, top = bottom, parent = NULL) {
 }
 data_pronoun_get <- function(x, nm) {
   if (!is_string(nm)) {
-    abort("Must subset the data pronoun with a string")
+    abort("Must subset the data pronoun with a string.")
   }
   mask <- .subset2(x, 1)
   .Call(rlang_data_pronoun_get, mask, sym(nm))
@@ -476,7 +451,7 @@ abort_data_pronoun <- function(nm) {
 }
 ctxt_pronoun_get <- function(x, nm) {
   if (!is_string(nm)) {
-    abort("Must subset the context pronoun with a string")
+    abort("Must subset the context pronoun with a string.")
   }
   eval_bare(sym(nm), x)
 }
