@@ -58,8 +58,7 @@ local_options <- function(..., .frame = caller_env()) {
   stopifnot(is_named(options))
 
   old <- options(options)
-  options_lang <- call2(base::options, !!! old)
-  local_exit(!! options_lang, frame = .frame)
+  defer(options(old), envir = .frame)
 
   invisible(old)
 }
@@ -102,7 +101,8 @@ peek_option <- function(name) {
 #'   escape hatch is useful in unit tests or to manually turn on
 #'   interactive features in RMarkdown outputs.
 #'
-#' * Whether knitr, an RStudio notebook, or testthat is in progress.
+#' * Whether knitr or testthat is in progress, in which case
+#'   `is_interactive()` returns `FALSE`.
 #'
 #' `with_interactive()` and `local_interactive()` set the global
 #' option conveniently.
@@ -121,9 +121,6 @@ is_interactive <- function() {
   if (is_true(peek_option("knitr.in.progress"))) {
     return(FALSE)
   }
-  if (is_true(peek_option("rstudio.notebook.executing"))) {
-    return(FALSE)
-  }
   if (identical(Sys.getenv("TESTTHAT"), "true")) {
     return(FALSE)
   }
