@@ -1,4 +1,5 @@
 #include "internal/arg.c"
+#include "internal/attr.c"
 #include "internal/call.c"
 #include "internal/dots.c"
 #include "internal/env.c"
@@ -8,6 +9,10 @@
 #include "internal/expr-interp.c"
 #include "internal/expr-interp-rotate.c"
 #include "internal/fn.c"
+#include "internal/hash.c"
 #include "internal/internal.c"
+#include "internal/nse-defuse.c"
 #include "internal/quo.c"
 #include "internal/utils.c"
+#include "internal/vec-raw.c"
+
