@@ -105,7 +105,7 @@ static sexp* new_condition_names(sexp* data) {
     r_abort("Conditions must have named data fields");
   }
 
-  sexp* data_nms = r_vec_names(data);
+  sexp* data_nms = r_names(data);
 
   if (r_chr_has_any(data_nms, (const char* []) { "message", NULL })) {
     r_abort("Conditions can't have a `message` data field");
@@ -121,7 +121,7 @@ static sexp* new_condition_names(sexp* data) {
 sexp* r_new_condition(sexp* subclass, sexp* msg, sexp* data) {
   if (msg == r_null) {
     msg = r_shared_empty_chr;
-  } else if (!r_is_scalar_character(msg)) {
+  } else if (!r_is_string(msg, NULL)) {
     r_abort("Condition message must be a string");
   }
 
@@ -184,7 +184,7 @@ void r_interrupt() {
 #endif
 
 enum r_condition_type r_cnd_type(sexp* cnd) {
-  sexp* classes = r_get_class(cnd);
+  sexp* classes = r_class(cnd);
   if (r_typeof(cnd) != r_type_list ||
       r_typeof(classes) != r_type_character) {
     goto error;
