@@ -43,3 +43,22 @@ skip_if_stale_backtrace <- local({
     skip_if(has_stale_backtrace)
   }
 })
+
+Rscript <- function(args, ...) {
+  out <- suppressWarnings(system2(
+    file.path(R.home("bin"), "Rscript"),
+    args,
+    ...,
+    stdout = TRUE,
+    stderr = TRUE
+  ))
+
+  list(
+    out = unstructure(out),
+    status = attr(out, "status")
+  )
+}
+
+expect_reference <- function(object, expected) {
+  expect_true(is_reference(object, expected))
+}
