@@ -1,9 +1,7 @@
-context("call")
-
 # Creation ----------------------------------------------------------------
 
 test_that("character vector must be length 1", {
-  expect_error(call2(letters), "must be a length 1 string")
+  expect_error(call2(letters), "must be a string")
 })
 
 test_that("args can be specified individually or as list", {
@@ -21,8 +19,18 @@ test_that("fails with non-callable objects", {
 })
 
 test_that("succeeds with literal functions", {
-  expect_error(regex = NA, call2(base::mean, 1:10))
-  expect_error(regex = NA, call2(base::list, 1:10))
+  expect_error(regexp = NA, call2(base::mean, 1:10))
+  expect_error(regexp = NA, call2(base::list, 1:10))
+})
+
+test_that("call2() preserves empty arguments", {
+  expect_identical(call2("[", quote(x), , drop = ), quote(x[, drop = ]))
+})
+
+test_that("call2() requires a symbol when namespace is supplied", {
+  expect_identical(call2("foo", .ns = "bar"), quote(bar::foo()))
+  expect_error(call2(function() NULL, .ns = "bar"), "must be a string or symbol")
+  expect_error(call2(quote(foo()), .ns = "bar"), "must be a string or symbol")
 })
 
 
@@ -160,6 +168,11 @@ test_that("is_call() pattern-matches", {
   expect_false(is_call(NULL))
 })
 
+test_that("quosures are not calls", {
+  skip("Disabled")
+  expect_false(is_call(quo()))
+})
+
 test_that("is_call() vectorises name", {
   expect_false(is_call(quote(foo::bar), c("fn", "fn2")))
   expect_true(is_call(quote(foo::bar), c("fn", "::")))
@@ -444,7 +457,8 @@ test_that("call_print_fine_type() returns correct enum", {
 })
 
 test_that("call_name() fails with namespaced objects (#670)", {
-  skip("Disabled for the 0.3.1 release")
+  expect_true(TRUE)
+  return("Disabled for the 0.3.1 release")
   expect_error(call_name(~foo::bar), "`call` must be a quoted call")
   expect_error(call_name(~foo:::bar), "`call` must be a quoted call")
 })
