@@ -1,5 +1,3 @@
-context("deparse")
-
 test_that("line_push() adds indentation", {
   out <- line_push("foo", "bar", width = 4, indent = 2)
   expect_identical(out, c("foo", "  bar"))
@@ -32,6 +30,7 @@ test_that("line_push() handles the nchar(line) == boundary case", {
 })
 
 test_that("line_push() strips ANSI codes before computing overflow", {
+  local_options(crayon.enabled = TRUE)
   if (!has_crayon()) {
     skip("test needs crayon")
   }
@@ -123,10 +122,12 @@ test_that("unspaced operators are deparsed", {
 })
 
 test_that("operands are wrapped in parentheses to ensure correct predecence", {
-  skip("FIXME r-devel")
   expect_identical_(sexp_deparse(expr(1 + !!quote(2 + 3))), "1 + (2 + 3)")
   expect_identical_(sexp_deparse(expr((!!quote(1^2))^3)), "(1^2)^3")
-  expect_identical_(sexp_deparse(quote(function() 1 ? 2)), "function() 1 ? 2")
+
+  skip_on_cran()
+  skip_if(getRversion() < "4.0.0")
+  expect_identical_(sexp_deparse(quote(function() 1 ? 2)), "(function() 1) ? 2")
   expect_identical_(sexp_deparse(expr(!!quote(function() 1) ? 2)), "(function() 1) ? 2")
 })
 
@@ -180,11 +181,15 @@ test_that("call_deparse() handles multi-line arguments", {
 })
 
 test_that("call_deparse() delimits CAR when needed", {
-  call <- expr((!!quote(function() x + 1))())
+  fn_call <- quote(function() x + 1)
+  call <- expr((!!fn_call)())
   expect_identical(call_deparse(call), "(function() x + 1)()")
 
-  # Only equal because of the extra parentheses
-  expect_equal(parse_expr(expr_deparse(call)), call)
+  roundtrip <- parse_expr(expr_deparse(call))
+  exp <- call2(call("(", fn_call))
+
+  # Zap srcref to work around https://github.com/r-lib/waldo/issues/59
+  expect_equal(zap_srcref(roundtrip), zap_srcref(exp))
 
   call <- expr((!!quote(f + g))(x))
   expect_identical(call_deparse(call), "`+`(f, g)(x)")
@@ -262,8 +267,9 @@ test_that("other objects are deparsed with base deparser", {
 })
 
 test_that("S3 objects are deparsed", {
+  skip_on_cran()
   expr <- expr(list(!!factor(1:3), !!structure(list(), class = c("foo", "bar", "baz"))))
-  expect_identical(sexp_deparse(expr), "list(<fct>, <S3: foo>)")
+  expect_identical(sexp_deparse(expr), "list(<fct>, <foo>)")
 })
 
 test_that("successive indentations on a single line are only counted once", {
@@ -384,14 +390,17 @@ test_that("as_label() handles literals", {
 })
 
 test_that("as_label() handles objects", {
-  expect_identical(as_label(mtcars), "<data.frame>")
-  expect_identical(as_label(structure(1, class = "foo")), "<S3: foo>")
+  skip_on_cran()
+  expect_identical(as_label(mtcars), "<df[,11]>")
+  expect_identical(as_label(structure(1, class = "foo")), "<foo>")
 })
 
 test_that("bracket deparsing is a form of argument deparsing", {
-  expect_identical(expr_deparse(call("[", iris, missing_arg(), drop = FALSE)), "<data.frame>[, drop = FALSE]")
   expect_identical(expr_deparse(quote(foo[bar, , baz()])), "foo[bar, , baz()]")
   expect_identical(expr_deparse(quote(foo[[bar, , baz()]])), "foo[[bar, , baz()]]")
+
+  skip_on_cran()
+  expect_identical(expr_deparse(call("[", iris, missing_arg(), drop = FALSE)), "<df[,5]>[, drop = FALSE]")
 })
 
 test_that("non-syntactic symbols are deparsed with backticks", {
@@ -401,7 +410,6 @@ test_that("non-syntactic symbols are deparsed with backticks", {
 })
 
 test_that("symbols with unicode are deparsed consistently (#691)", {
-  skip_unless_utf8()
   skip_if(getRversion() < "3.2")
 
   expect_identical(expr_text(sym("\u00e2a")), "\u00e2a")
@@ -420,8 +428,9 @@ test_that("empty blocks are deparsed on the same line", {
 })
 
 test_that("top-level S3 objects are deparsed", {
+  skip_on_cran()
   f <- structure(function() { }, class = "lambda")
-  expect_identical(expr_deparse(f), "<S3: lambda>")
+  expect_identical(expr_deparse(f), "<lambda>")
 })
 
 # This test causes a parsing failure in R CMD check >= 3.6
@@ -466,3 +475,48 @@ test_that("infix operators are sticky", {
   expect_identical(expr_deparse(quote(foo %>% bar), width = 3L), c("foo %>%", "  bar"))
   expect_identical(expr_deparse(quote(foo + bar), width = 3L), c("foo +", "  bar"))
 })
+
+test_that("argument names are backticked if needed (#950)", {
+  expect_identical(expr_deparse(quote(list(`a b` = 1))), "list(`a b` = 1)")
+})
+
+test_that("`next` and `break` are deparsed", {
+  expect_equal(expr_deparse(quote({ next; (break) })), c("{", "  next",  "  (break)", "}"))
+  expect_equal(expr_deparse(quote(a <- next <- break)), c("a <- next <- break"))
+})
+
+test_that("double colon is never wrapped (#1072)", {
+  expect_identical(
+    expr_deparse(quote(some.very.long::construct), width = 20),
+    "some.very.long::construct"
+  )
+  expect_identical(
+    expr_deparse(quote(id_function <- base::identity), width = 15),
+    c(
+      "id_function <-",
+      "  base::identity"
+    )
+  )
+  expect_identical(
+    expr_deparse(quote(id_fun <- base::identity), width = 20),
+    "id_fun <- base::identity"
+  )
+})
+
+test_that("triple colon is never wrapped (#1072)", {
+  expect_identical(
+    expr_deparse(quote(some.very.long:::construct), width = 20),
+    "some.very.long:::construct"
+  )
+  expect_identical(
+    expr_deparse(quote(id_function <- base:::identity), width = 15),
+    c(
+      "id_function <-",
+      "  base:::identity"
+    )
+  )
+  expect_identical(
+    expr_deparse(quote(id_fun <- base:::identity), width = 20),
+    "id_fun <- base:::identity"
+  )
+})
